@@ -1,5 +1,3 @@
 package C::D::F::G;
-
-sub answer { 42 };
-
+sub answer { 42 }
 1;
